@@ -2,7 +2,7 @@
 
    GNU Chess engine
 
-   Copyright (C) 2001-2011 Free Software Foundation, Inc.
+   Copyright (C) 2001-2025 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -108,6 +108,8 @@ static const int FreePasser = 60;
 static const int AttackerDistance = 5;
 static const int DefenderDistance = 20;
 
+static const int TempoBonus = 10;
+
 // "constants"
 
 static const int KingAttackWeight[16] = {
@@ -292,6 +294,14 @@ int eval(const board_t * board) {
    phase = mat_info->phase;
    eval = ((opening * (256 - phase)) + (endgame * phase)) / 256;
 
+   // tempo bonus
+
+   if (COLOUR_IS_WHITE(board->turn)) {
+      eval += TempoBonus;
+   } else {
+      eval -= TempoBonus;
+   }
+
    // drawish bishop endgames
 
    if ((mat_info->flags & DrawBishopFlag) != 0) {
