@@ -2,7 +2,7 @@
 
    GNU Chess frontend
 
-   Copyright (C) 2001-2021 Free Software Foundation, Inc.
+   Copyright (C) 2001-2025 Free Software Foundation, Inc.
 
    GNU Chess is based on the two research programs
    Cobalt by Chua Kong-Sian and Gazebo by Stuart Cracraft.
@@ -394,7 +394,7 @@ void cmd_load(void)
     printf (_("Board is wrong!\n"));
   } else {
     /* Read EPD file and send contents to engine */
-    if (build_setboard_cmd_from_epd_file(data, epd_filename, strlen(data))) {
+    if (build_setboard_cmd_from_epd_file(data, epd_filename, sizeof(data))) {
       SetDataToEngine( data );
       SetAutoGo( true );
     } else {
@@ -812,55 +812,59 @@ void cmd_usage(void)
       printf ( "\n" );
       printf ( _("\
 Usage: %s [OPTION]...\n\n"), progname );
-      fputs( _("\
-Play the game of chess.\n\n"), stdout );
-      fputs( _("Options:\n"), stdout );
-      fputs( _("\
- -h, --help         display this help and exit\n"), stdout );
-      fputs( _("\
- -v, --version      display version information and exit\n"), stdout );
-      fputs( _("\
- -q, --quiet        make the program silent on startup\n"), stdout );
-      fputs( _("\
-     --silent       same as -q\n"), stdout );
-      fputs( _("\
-\n"), stdout );
-      fputs( _("\
- -x, --xboard       start in engine mode\n"), stdout );
-      fputs( _("\
- -p, --post         start up showing thinking\n"), stdout );
-      fputs( _("\
- -e, --easy         disable thinking in opponents time\n"), stdout );
-      fputs( _("\
- -m, --manual       enable manual mode\n"), stdout );
-      fputs( _("\
- -u, --uci          enable UCI protocol (externally behave as UCI engine)\n"), stdout );
-      fputs( _("\
- -M size, --memory=size   specify memory usage in MB for hashtable\n"), stdout );
-      fputs( _("\
- -a filename, --addbook=filename   compile book.bin from pgn book 'filename'\n"), stdout );
-      fputs( _("\
- -g, --graphic      enable graphic mode\n"), stdout );
-      fputs( _("\
-\n"), stdout );
-      fputs( _("\
- Options xboard and post are accepted without leading dashes\n\
- for backward compatibility.\n\
-\n"), stdout );
-      fputs( _("\
- Moves are accepted either in standard algebraic notation (SAN) or\n\
- in coordinate algebraic notation.\n\
-\n"), stdout );
-      fputs( _("\
- The file 'gnuchess.ini' allows setting config options if --uci is not\n\
- used. See 'info gnuchess' for details. The file is looked for in three\n\
- locations according to this precedence: current directory, the\n\
- directory pointed to by environment variable GNUCHESS_PKGDATADIR,\n\
- or the package data directory stated at configure time.\n\
-\n"), stdout );
-      fputs( _("\
-Report bugs to <bug-gnu-chess@gnu.org>.\n\
-\n"), stdout );
+      printf( _("\
+Play the game of chess.\n\n") );
+      printf( _("Options:\n") );
+      printf( _("\
+ -h, --help                        display this help and exit\n") );
+      printf( _("\
+ -v, --version                     display version information and exit\n") );
+      printf( _("\
+ -q, --quiet                       make the program silent on startup\n") );
+      printf( _("\
+     --silent                      same as -q\n") );
+      printf( _("\
+\n") );
+      printf( _("\
+ -x, --xboard                      start in engine mode\n") );
+      printf( _("\
+ -p, --post                        start up showing thinking\n") );
+      printf( _("\
+ -e, --easy                        disable thinking in opponents time\n") );
+      printf( _("\
+ -m, --manual                      enable manual mode\n") );
+      printf( _("\
+ -u, --uci                         enable UCI protocol (that is: behave like an\n\
+                                   UCI engine); incompatible with other options\n") );
+      printf( _("\
+ -M SIZE, --memory=SIZE            specify memory usage in MB for hashtable\n") );
+      printf( _("\
+ -a FILENAME, --addbook=FILENAME   compile book.bin from pgn book FILENAME\n") );
+      printf( _("\
+ -g, --graphic                     enable graphic mode\n") );
+      printf( _("\
+\n") );
+      printf( _("\
+Options xboard and post are accepted without leading dashes\n\
+for backward compatibility.\n\
+\n") );
+      printf( _("\
+Moves are accepted either in standard algebraic notation (SAN) or\n\
+in coordinate algebraic notation.\n\
+\n") );
+      printf( _("\
+The file 'gnuchess.ini' allows setting configuration options, but it is\n\
+ignored if the --uci option is used. See 'info gnuchess' for details\n\
+about the options. The program will look for 'gnuchess.ini' in\n\
+$XDG_CONFIG_HOME/gnuchess/ and $HOME/.config/gnuchess/ in that order,\n\
+and it will use the first one it finds, if any.\n\
+\n") );
+      printf( _("\
+Report bugs to: <bug-gnu-chess@gnu.org>.\n") );
+      printf( _("\
+%s home page: <https://www.gnu.org/software/chess/>\n"), PACKAGE_NAME );
+      printf( _("\
+General help using GNU software: <https://www.gnu.org/gethelp/>\n\n") );
      }
 
 
@@ -913,10 +917,13 @@ void cmd_usermove(void)
 
 void cmd_version(void)
 {
-   if (!(flags & XBOARD))
-     printf ("%s %s\n", PROGRAM, VERSION);
-   else
-     printf ("Chess\n");
+    printf ("%s\n", PACKAGE_STRING);
+    printf ( _("\
+Copyright (C) %s Free Software Foundation, Inc.\n\
+License GPLv3+: GNU GPL version 3 or later <https://gnu.org/licenses/gpl.html>\n\
+This is free software: you are free to change and redistribute it.\n\
+There is NO WARRANTY, to the extent permitted by law.\n"),
+             "2025" );
 }
 
 void cmd_coords(void) {
@@ -1048,7 +1055,7 @@ static const char * const helpstr[] = {
    "help",
    gettext_noop(" Produces a help blurb corresponding to this list of commands."),
    "book",
-   gettext_noop(" add - compiles book.bin from a pgn book file"),
+   gettext_noop(" add FILENAME - compiles book.bin from pgn book FILENAME"),
    gettext_noop(" on - enables use of book (default)"),
    gettext_noop(" off - disables use of book"),
    gettext_noop(" worst - plays worst move from book"),
